@@ -1,9 +1,10 @@
 try:
-    from normatrix.source.file_parser import CFileParse
     from normatrix.source.config import TypeLine
+    from normatrix.source.file_parser import CFileParse
 except ModuleNotFoundError:
-    from src.normatrix.source.file_parser import CFileParse
     from src.normatrix.source.config import TypeLine
+    from src.normatrix.source.file_parser import CFileParse
+
 
 def check(context, file: CFileParse) -> (int, int, list):
     nb_error = 0
@@ -17,12 +18,10 @@ def check(context, file: CFileParse) -> (int, int, list):
             continue
         nb_space = 0
         len_l = len(line[1])
-        while len_l > 0 and nb_space < len_l and line[1][nb_space] == ' ':
+        while len_l > 0 and nb_space < len_l and line[1][nb_space] == " ":
             nb_space += 1
         if nb_space % 4 != 0:
-            list_error.append(
-                    (i + 1, f"always four indent in source code ({line[1]})")
-            )
+            list_error.append((i + 1, f"always four indent in source code ({line[1]})"))
             nb_error += 1
         if not (file.basename.endswith(".c") or file.basename.endswith(".h")):
             continue
