@@ -1,25 +1,23 @@
 try:
-    from normatrix.source.file_parser import CFileParse
     from normatrix.source.config import TypeLine
     from normatrix.source.context import Context
-    from normatrix.source.config import LIBC_BANNED_FUNC
     from normatrix.source.custom_regex import re_search, re_sub
+    from normatrix.source.file_parser import CFileParse
 except ModuleNotFoundError:
-    from src.normatrix.source.file_parser import CFileParse
     from src.normatrix.source.config import TypeLine
     from src.normatrix.source.context import Context
-    from src.normatrix.source.config import LIBC_BANNED_FUNC
     from src.normatrix.source.custom_regex import re_search, re_sub
+    from src.normatrix.source.file_parser import CFileParse
 
-import re
 
 def check_libcfunc(context: Context, line: str) -> (bool, str):
     for elem in context.LIBC_BANNED_FUNC:
-        m = re_search(f"\W{elem}\(", line, timeout=0.1)
-        if m != None:
+        m = re_search(rf"\W{elem}\(", line, timeout=0.1)
+        if m:
             return (True, elem)
     return (False, "")
 
+
 def check(context: Context, file: CFileParse) -> (int, int, list):
     nb_error = 0
     list_error = []
@@ -29,7 +27,7 @@ def check(context: Context, file: CFileParse) -> (int, int, list):
     for i in range(len(file.sub_parsedline)):
         line = file.sub_parsedline[i]
         if line[0] != TypeLine.COMMENT:
-            ll = re_sub('\/\/.*', '', line[1], timeout=0.1)
+            ll = re_sub(r"\/\/.*", "", line[1], timeout=0.1)
             ok, func = check_libcfunc(context, ll)
             if ok:
                 list_error.append((i + 1, f"no libc func ({func})"))
