@@ -1,13 +1,12 @@
 try:
-    from normatrix.source.file_parser import CFileParse
     from normatrix.source.config import TypeLine
     from normatrix.source.custom_regex import re_search, re_sub
+    from normatrix.source.file_parser import CFileParse
 except ModuleNotFoundError:
-    from src.normatrix.source.file_parser import CFileParse
     from src.normatrix.source.config import TypeLine
     from src.normatrix.source.custom_regex import re_search, re_sub
+    from src.normatrix.source.file_parser import CFileParse
 
-import re
 
 def check(context, file: CFileParse) -> (int, int, list):
     nb_error = 0
@@ -18,13 +17,11 @@ def check(context, file: CFileParse) -> (int, int, list):
     for i, line in enumerate(file.sub_parsedline):
         if line[0] == TypeLine.COMMENT:
             continue
-        ll = re_sub(".*?\*\/", '', line[1], timeout=0.1)
-        ll = re_sub("\/\*.*", '', ll, timeout=0.1)
-        ll = re_sub("//.*", '', ll, timeout=0.1)
-        m = re_search('(\[ )|( \])', ll, timeout=0.1)
-        if m != None:
-            list_error.append(
-                    (i + 1, f"no space after [ or before ] ({line[1]})")
-            )
+        ll = re_sub(r".*?\*\/", "", line[1], timeout=0.1)
+        ll = re_sub(r"\/\*.*", "", ll, timeout=0.1)
+        ll = re_sub(r"//.*", "", ll, timeout=0.1)
+        m = re_search(r"(\[ )|( \])", ll, timeout=0.1)
+        if m:
+            list_error.append((i + 1, f"no space after [ or before ] ({line[1]})"))
             nb_error += 1
     return (nb_error, 0, list_error)
